@@ -1,13 +1,14 @@
-from typing import Union
+from typing import Type, Union
 
-from vedro.core import Dispatcher, Plugin
+from vedro.core import Dispatcher, Plugin, PluginConfig
 from vedro.events import ArgParsedEvent, ArgParseEvent, StartupEvent
 
-__all__ = ("Tagger",)
+__all__ = ("Tagger", "TaggerPlugin",)
 
 
-class Tagger(Plugin):
-    def __init__(self) -> None:
+class TaggerPlugin(Plugin):
+    def __init__(self, config: Type["Tagger"]) -> None:
+        super().__init__(config)
         self._tags: Union[str, None] = None
 
     def subscribe(self, dispatcher: Dispatcher) -> None:
@@ -21,10 +22,14 @@ class Tagger(Plugin):
     def on_arg_parsed(self, event: ArgParsedEvent) -> None:
         self._tags = event.args.tags
 
-    def on_startup(self, event: StartupEvent) -> None:
+    async def on_startup(self, event: StartupEvent) -> None:
         if self._tags is None:
             return
-        for scenario in event.scenarios:
+        async for scenario in event.scheduler:
             tags = getattr(scenario._orig_scenario, "tags", ())
             if self._tags not in tags:
-                scenario.skip()
+                event.scheduler.ignore(scenario)
+
+
+class Tagger(PluginConfig):
+    plugin = TaggerPlugin
